Struct product_os_server::conn::SendRequest
source · pub struct SendRequest<B> { /* private fields */ }Expand description
The sender side of an established connection.
Implementations
sourceimpl<B> SendRequest<B>
impl<B> SendRequest<B>
sourceimpl<B> SendRequest<B>where
B: Body + 'static,
impl<B> SendRequest<B>where B: Body + 'static,
sourcepub fn send_request(&mut self, req: Request<B>) -> ResponseFuture ⓘ
pub fn send_request(&mut self, req: Request<B>) -> ResponseFuture ⓘ
Sends a Request on the associated connection.
Returns a future that if successful, yields the Response.
Note
There are some key differences in what automatic things the Client
does for you that will not be done here:
Clientrequires absolute-formUris, since the scheme and authority are needed to connect. They aren’t required here.- Since the
Clientrequires absolute-formUris, it can add theHostheader based on it. You must add aHostheader yourself before calling this method. - Since absolute-form
Uris are not required, if received, they will be serialized as-is.
Example
use hyper::Request;
// build a Request
let req = Request::builder()
.uri("/foo/bar")
.header(HOST, "hyper.rs")
.body(Body::empty())
.unwrap();
// send it and await a Response
let res = tx.send_request(req).await?;
// assert the Response
assert!(res.status().is_success());Trait Implementations
sourceimpl<B> Debug for SendRequest<B>
impl<B> Debug for SendRequest<B>
sourceimpl<B> Service<Request<B>> for SendRequest<B>where
B: Body + 'static,
impl<B> Service<Request<B>> for SendRequest<B>where B: Body + 'static,
type Future = ResponseFuture
type Future = ResponseFuture
The future response value.