ProductOSRouter

Enum ProductOSRouter 

pub enum ProductOSRouter<S = ()> {
    Axum(AxumRouter<S>),
}
Main router enum for Product OS Router

Dispatches to either Axum or Flow implementation based on feature flags. Provides a high-level API for defining routes, handlers, and middleware. Supports both stateful and stateless routing.

Type Parameters

  • S - The state type (defaults to () for stateless routing)

Examples

Stateless Router

use product_os_router::ProductOSRouter;

async fn handler() -> &'static str {
    "Hello!"
}

let mut router = ProductOSRouter::new();
router.add_get_no_state("/", handler);

Stateful Router

use product_os_router::{ProductOSRouter, State};

#[derive(Clone)]
struct AppState {
    message: String,
}

async fn handler(State(state): State<AppState>) -> String {
    state.message
}

let state = AppState { message: "Hello!".to_string() };
let mut router = ProductOSRouter::new_with_state(state);
router.add_get("/", handler);

Variants



Axum(AxumRouter<S>)

Implementations

Source

impl<S> ProductOSRouter<S>
where S: Clone + Send + Sync + 'static,

pub fn new_with_state(state: S) -> ProductOSRouter<S>

Create a new router with the given shared state.

Source

impl ProductOSRouter

pub fn new() -> ProductOSRouter

Create a new stateless router

Creates a router without any shared state. Use new_with_state if you need to share state between handlers.

Examples
use product_os_router::ProductOSRouter;

let router = ProductOSRouter::new();
Source

impl ProductOSRouter

pub fn param_to_field(path: &str) -> String

Convert path parameters from Express-style to Axum format

pub fn not_implemented() -> Response<Body>

Returns a 501 Not Implemented JSON response

pub fn not_implemented_legacy() -> Response<Body>

👎Deprecated since 0.0.41:

Use not_implemented() which correctly returns 501, or build a 404 response explicitly

Returns a 404 Not Found JSON response

pub fn add_get_no_state<H, T>(&mut self, path: &str, handler: H)
where H: Handler<T, ()> + Send + Sync + 'static, T: 'static,

Add a GET route handler without state

pub fn add_post_no_state<H, T>(&mut self, path: &str, handler: H)
where H: Handler<T, ()> + Send + Sync + 'static, T: 'static,

Add a POST route handler without state

pub fn add_handler_no_state<H, T>( &mut self, path: &str, method: Method, handler: H, )
where H: Handler<T, ()> + Send + Sync + 'static, T: 'static,

Add a handler for the given HTTP method without state

pub fn add_default_header_no_state( &mut self, header_name: &str, header_value: &str, )

Add a default header without state

pub fn set_fallback_handler_no_state<H, T>(&mut self, handler: H)
where H: Handler<T, ()> + Send + Sync + 'static, T: 'static,

Set a fallback handler without state

pub fn add_handlers_no_state<H, T>( &mut self, path: &str, handlers: BTreeMap<Method, H>, )
where H: Handler<T, ()> + Send + Sync + 'static, T: 'static,

Add multiple handlers without state

Source

impl<S> ProductOSRouter<S>
where S: Clone + Send + Sync + 'static,

pub fn get_router(&self) -> ProductOSRouter<S>

Return a clone of the router.

For both Axum and Flow, returns ProductOSRouter<S>. Use into_axum_router() when you need the raw axum::Router.

pub fn into_axum_router(self) -> Router

Extract the inner axum::Router, consuming the wrapper.

This is needed when handing the router to axum-specific server functions that expect a raw axum::Router.

pub fn add_get<H, T>(&mut self, path: &str, handler: H)
where H: Handler<T, S> + Send + Sync + 'static, T: 'static,

Add a GET route handler

pub fn add_post<H, T>(&mut self, path: &str, handler: H)
where H: Handler<T, S> + Send + Sync + 'static, T: 'static,

Add a POST route handler

pub fn add_handler<H, T>(&mut self, path: &str, method: Method, handler: H)
where H: Handler<T, S> + Send + Sync + 'static, T: 'static,

Add a handler for the given HTTP method and path

pub fn add_default_header(&mut self, header_name: &str, header_value: &str)

Add a default header

pub fn add_handlers<H, T>(&mut self, path: &str, handlers: BTreeMap<Method, H>)
where H: Handler<T, S> + Send + Sync + 'static, T: 'static,

Add multiple HTTP method handlers at a single path

pub fn add_route(&mut self, path: &str, method_router: MethodRouter<S>)
where S: Clone + Send + Sync + 'static,

Add a route with an Axum MethodRouter.

pub fn set_fallback(&mut self, service_handler: MethodRouter<S>)
where S: Clone + Send + Sync + 'static,

Set the fallback service for unmatched routes (Axum MethodRouter).

pub fn set_fallback_handler<H, T>(&mut self, handler: H)
where H: Handler<T, S>, T: 'static,

Set the fallback handler for unmatched routes.

pub fn add_middleware<L, ResBody>(&mut self, middleware: L)
where L: Layer<Route> + Clone + Send + Sync + 'static, <L as Layer<Route>>::Service: Service<Request<Body>, Response = Response<ResBody>> + Clone + Send + Sync + 'static, <<L as Layer<Route>>::Service as Service<Request<Body>>>::Future: Send, <<L as Layer<Route>>::Service as Service<Request<Body>>>::Error: Into<Box<dyn Error + Send + Sync>>, ResBody: Body<Data = Bytes> + Send + 'static, <ResBody as Body>::Error: Into<Box<dyn Error + Send + Sync>>,

Add an Axum-compatible Tower middleware layer.

Source

impl<S> ProductOSRouter<S>
where S: Clone + Send + Sync + 'static,

pub fn add_extension<T>(&mut self, value: T)
where T: Clone + Send + Sync + 'static,

Inserts a value into request extensions for all subsequent handlers.